//  Package Tracker 2.1.5
//  Copyright (c) 2005 Monkey Business Labs
//  http://www.monkeybusinesslabs.com/

var trackingNumber;
var backShown = false;

var estimateLabel = "Est. Delivery: ";
var currentLabel  = "Current: ";
var drawerAnimationTime = 250;

var baseHeight    = 129;
var drawerHeight  = 33 + 33;
var sectionHeight = 39;
var padHeight     = 0;
var maxRows       = 4;
var drawerOffset  = 84;

var middleHeight  = (sectionHeight + padHeight) * maxRows - padHeight;
var pushedIn      = drawerHeight + middleHeight;

var drawerSections = new Array();
var drawerAnimator = new Animator(setDrawerIn, pushedIn);

var trackerView;

function setup()
{
    // Set up handlers if running under Dashboard
    if (window.widget) {
        widget.onhide = onhide;
        widget.onshow = onshow;
    }

    // Set up the done button on our back side
    createGenericButton(document.getElementById("doneButton"), "Done", hidePrefs, 67);

    // Clear out the placeholder text
    resetDisplay();
    closeDrawer();
    document.getElementById("trackingField").value = "";

    // Start with the tracker selector
    selectTracker("Select");
    
    return 0;
}

function selectTracker(whichTracker) {
    // Abort any pending request
    if (xmlReq)
        xmlReq.abort();

    // Give the existing view a chance to clean up
    if (trackerView) trackerView.goAway(event);
    
    // Replace it
    trackerView = new TrackerView(whichTracker);
    trackerView.init();
    
    // Do on-screen event
    setTimeout('onshow()', 0);
}

// Widget has come on screen, so update
function onshow() {
    if (backShown == false)
        trackerView.onShow();
}

// Widget has gone away, but we don't really care
function onhide() {
    // Stub
}

// Called when a tracking number is entered
function readField(field) {
    // XXX Some more validation here might not hurt
    if (field.value != null && field.value.length)
        trackingNumber = field.value;
    else
        trackingNumber = null;
    onshow();

    return true;
}

function readFieldEnter(field) {
    // Enter pressed?
    if (window.event.keyCode == 13) {
        readField(field)
    }
    
    return true;
}

// Update one of the widget's status elements
function setMessage(element, message) {
    var stat_element = document.getElementById(element);
    stat_element.innerHTML = message;
}

// Request the status page
function updateStatus() {
    if (trackingNumber) {
        setMessage("widget-status", "Getting package status...");

        trackerView.requestStatus();
    }
    else {
        resetDisplay();
        closeDrawer();
        setMessage("widget-status", "Enter Tracking Number");
    }
}

function findNodeValue(aNode) {
    // If it's text, just return it
    if (aNode.nodeValue != null)
        return aNode.nodeValue;
    
    // Otherwise, concatenate the contents of the children
    var childText = "";
    var nodeChild = aNode.firstChild;
    while (nodeChild) {
        childText += findNodeValue(nodeChild) + " ";
        nodeChild = nodeChild.nextSibling;
    }
    return childText;
}

// Return the text contents of a table cell, with tags and whitespace removed
function cleanCell(cell) {
    cell.normalize();
    // Try to find the innermost text, which may be surrounded by <b></b> or whatever
    var cellString = findNodeValue(cell);

    var cellText = new String(cellString);
    // Convert nbsp to space
    cellText = cellText.replace(/\xa0/g, " ");
    // Remove junk
    cellText = cellText.replace(/[^\w:,'\.\/ ]+/g, "");
    // Remove whitespace
    cellText = cellText.replace(/^\s*(.*?)\s*$/, "$1");
    if (cellText.length == 0) cellText = null;

    return cellText;
}

// Generate tags for label: value
function labeledValue(label, value) {
    var result = "";

    if (label != null)
        result += "<span class='status-label'>" + label + "</span>";
    if (value != null)
        result += "<span class='status-value'>" + value + "</span>";
    
    return result;
}

function showDrawer() {
    document.getElementById("drawer").style.display = "block";
}

function hideDrawer() {
    document.getElementById("drawer").style.display = "none";
}

function setDrawerIn(amount) {
    var drawer = document.getElementById("drawer");
    drawer.style.clip = "rect(" + amount + "px auto auto auto)";
    drawer.style.top  = (drawerOffset - amount) + "px";
}

function closeDrawer() {
    drawerAnimator.animateTo(pushedIn, drawerAnimationTime, hideDrawer);
}

function animateDrawerTo(newPosition, doneNotification) {
    showDrawer();
    drawerAnimator.animateTo(newPosition, drawerAnimationTime, doneNotification);
}

function wrapSection(num, text) {
    var rowParity = "even";
    if (num % 2)
        rowParity = "odd";

    return("<div class='drawer-row-" + rowParity + "'>"
         +   "<div class='drawer-text'>"
         +   text
         +   "</div>"
         + "</div>");
}

function setDrawerContents() {
    if (drawerSections.length == 0) {
        closeDrawer();
    }
    else {
        var sectionText = "";
        var numSections  = 0;
        for (pad = drawerSections.length; pad < maxRows; pad++) {
            numSections++;
            sectionText += wrapSection(numSections, "");
        }
        for (s in drawerSections) {
            numSections++;
            sectionText += wrapSection(numSections, drawerSections[s]);
        }
        setMessage("drawer-middle", sectionText);
        middleHeight = (sectionHeight + padHeight) * numSections - padHeight;
        window.resizeTo(document.width, baseHeight + drawerHeight + middleHeight);
        document.getElementById("drawer-middle").style.height = middleHeight;
        animateDrawerTo((sectionHeight + padHeight) * (maxRows - drawerSections.length));
    }
}

// Blank everything out
function resetDisplay() {
    setMessage("estimate", "");
    setMessage("current", "");
    setMessage("error", "");
    
    setMessage("widget-status", "");
    if (trackerView)
        trackerView.setDelivered(false);
}

// Mouseover events for Monkey Business logo
function enterLogo(event) {
    document.getElementById("mb-logo-glow").style.visibility = "visible";
}

function exitLogo(event) {
    document.getElementById("mb-logo-glow").style.visibility = "hidden";
}

// Generic image swap
function bgSwap(divId, imageUrl) {
    document.getElementById(divId).style.background = "url(images/" + imageUrl + ")";
}

// Mouseover events for carrier selector
function overSelector(event, carrier) {
    bgSwap("selector-cap", "Select/" + carrier + ".png");
}

function downSelector(event, carrier) {
    bgSwap("selector-cap", "Select/" + carrier + "_hl.png");
}

// Link to the tracking web site when status is clicked
function goToTrackingSite() {
    if (trackingNumber != null) {
        wrapURL(trackerView.trackingUrl(trackingNumber));
    }
}

function wrapURL(URL) {
    if (window.widget)
        widget.openURL(URL);
    else
        window.location = URL;
}
